var group___terrain =
[
    [ "Ogre::Terrain", "class_ogre_1_1_terrain.html", [
      [ "DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html", [
        [ "DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#aefc4903a668c681052b0a0186b4f5bc9", null ],
        [ "~DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#acc6a126be76a2f958d24c940ca42a8e3", null ],
        [ "allocateVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#a698d20967fcd629365ec575e3bdddc4a", null ],
        [ "freeVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#abbab9b7b467b4783b9a43ac18261c0cf", null ],
        [ "getSharedIndexBuffer", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#ab64c66761d093b621a75d68fa94c9d23", null ],
        [ "freeAllBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#af2ae0b441f30b0204815e46aba27725b", null ],
        [ "warmStart", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#ad52747460145f8b432fdfe7da0512057", null ]
      ] ],
      [ "GpuBufferAllocator", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html", [
        [ "GpuBufferAllocator", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#adafa196fd89b566090806bde188bbf33", null ],
        [ "~GpuBufferAllocator", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ab50e9928256ddbd09462938a7e13e3c8", null ],
        [ "allocateVertexBuffers", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#a3c10273ba4790cfbd48b93e2627f85c2", null ],
        [ "freeVertexBuffers", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ac70a9dbc1dcfc9c742c08a7714ed7fa3", null ],
        [ "getSharedIndexBuffer", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#a826a5d2848be329361177f0209c13a67", null ],
        [ "freeAllBuffers", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ac35a15958d618f6e9cb9b2ca6663e219", null ]
      ] ],
      [ "ImportData", "struct_ogre_1_1_terrain_1_1_import_data.html", [
        [ "ImportData", "struct_ogre_1_1_terrain_1_1_import_data.html#a4051612dde80d254c9761343a66bf47e", null ],
        [ "ImportData", "struct_ogre_1_1_terrain_1_1_import_data.html#a94c34664786d5059f7a9ef36e061890e", null ],
        [ "~ImportData", "struct_ogre_1_1_terrain_1_1_import_data.html#ab44221d85f1c10b8c2be75b476d89440", null ],
        [ "operator=", "struct_ogre_1_1_terrain_1_1_import_data.html#a9a0932d90bd71328abb811d53bee5a02", null ],
        [ "destroy", "struct_ogre_1_1_terrain_1_1_import_data.html#a7a5f66953eabbc5221f36ee476f98d47", null ],
        [ "terrainAlign", "struct_ogre_1_1_terrain_1_1_import_data.html#a9cc48b1e14f6974f46bf9da947f8fc76", null ],
        [ "terrainSize", "struct_ogre_1_1_terrain_1_1_import_data.html#a0b5bc1f24bcc9003e5ed0ccb850711f8", null ],
        [ "maxBatchSize", "struct_ogre_1_1_terrain_1_1_import_data.html#acebf6cfa7dcb63b4725ed1dc2e63a9f2", null ],
        [ "minBatchSize", "struct_ogre_1_1_terrain_1_1_import_data.html#a60b1682048188053cc885097eb2383c6", null ],
        [ "pos", "struct_ogre_1_1_terrain_1_1_import_data.html#ade0d3e9baacc9408bc08ce2531f177b4", null ],
        [ "worldSize", "struct_ogre_1_1_terrain_1_1_import_data.html#a43509d8a986b1b733d010300487425a5", null ],
        [ "inputImage", "struct_ogre_1_1_terrain_1_1_import_data.html#a61b189d3b9768810d747f35f7d141e79", null ],
        [ "inputFloat", "struct_ogre_1_1_terrain_1_1_import_data.html#aaab91a388f7bab0e1d00a858bbeb5902", null ],
        [ "constantHeight", "struct_ogre_1_1_terrain_1_1_import_data.html#a210633812bf4ae671e19736a934079b3", null ],
        [ "deleteInputData", "struct_ogre_1_1_terrain_1_1_import_data.html#ab5bbdf7852ee1d2192c421c17df237e7", null ],
        [ "inputScale", "struct_ogre_1_1_terrain_1_1_import_data.html#ae97c725c89e0c789e5099fd387953020", null ],
        [ "inputBias", "struct_ogre_1_1_terrain_1_1_import_data.html#aa92240ffea408a3ff250e8e8233789bb", null ],
        [ "layerDeclaration", "struct_ogre_1_1_terrain_1_1_import_data.html#ae3203cf7a78bd3ed0cd75ffe3c107a2e", null ],
        [ "layerList", "struct_ogre_1_1_terrain_1_1_import_data.html#a3d892ce610f8e6aec873528d042fe72b", null ]
      ] ],
      [ "LayerInstance", "struct_ogre_1_1_terrain_1_1_layer_instance.html", [
        [ "LayerInstance", "struct_ogre_1_1_terrain_1_1_layer_instance.html#aa554bc0d00ec43b9fb48cf9a436112c2", null ],
        [ "worldSize", "struct_ogre_1_1_terrain_1_1_layer_instance.html#a54f726e8a0c17ec1579a16afa1a9398c", null ],
        [ "textureNames", "struct_ogre_1_1_terrain_1_1_layer_instance.html#a14363e8e526e90ea47ea93cac3764fc1", null ]
      ] ],
      [ "RealVector", "class_ogre_1_1_terrain.html#a73ee350d02e7d9805db61c740afcab87", null ],
      [ "LayerInstanceList", "class_ogre_1_1_terrain.html#a24f7a399f8e60b335776064227b869d6", null ],
      [ "Alignment", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91", [
        [ "ALIGN_X_Z", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91ac4699c4f99bea344a309d5544b33c140", null ],
        [ "ALIGN_X_Y", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91adfc96b5a388b3e48709d56b899098508", null ],
        [ "ALIGN_Y_Z", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91add646ddae48fd0c7cc9c0a74458feb42", null ]
      ] ],
      [ "NeighbourIndex", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2", [
        [ "NEIGHBOUR_EAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a88c6e2c93031bba254272861a1664cc3", null ],
        [ "NEIGHBOUR_NORTHEAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2aed82e8f7f45fcb5faeef6158c9d1ff3a", null ],
        [ "NEIGHBOUR_NORTH", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a07b3c537d34f5c7e1e3e79634dfcac1d", null ],
        [ "NEIGHBOUR_NORTHWEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a8795dff5bfc2240747ee0a843a900c71", null ],
        [ "NEIGHBOUR_WEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a3a45b8d00d2ba435e61cdc99c94b0a91", null ],
        [ "NEIGHBOUR_SOUTHWEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2aec43a04404ef9873e7d43c094e097e40", null ],
        [ "NEIGHBOUR_SOUTH", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a8c91ce1d5f82d7525102bc91fde0df2d", null ],
        [ "NEIGHBOUR_SOUTHEAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a4183a4a8b0f78832395fa0aa981f07bf", null ],
        [ "NEIGHBOUR_COUNT", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a5ba448a51833e6c8eea28884a706834c", null ]
      ] ],
      [ "Space", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781", [
        [ "WORLD_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a0a7049246e4a77e37dcea36fd35c4daf", null ],
        [ "LOCAL_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781ae3eabb53019f0d4ecfbff1d9a417d907", null ],
        [ "TERRAIN_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a0ad91edc61b2fb7ebe1966fc167ffe6d", null ],
        [ "POINT_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a748f0b5f2b54c63be96965de53931de6", null ]
      ] ],
      [ "Terrain", "class_ogre_1_1_terrain.html#a9cc3d8901c73b6d2b6e1613a22636801", null ],
      [ "~Terrain", "class_ogre_1_1_terrain.html#ad3516cbdabc73135b79f1d34ffda7f01", null ],
      [ "getSceneManager", "class_ogre_1_1_terrain.html#a29b325c5180def04910d06b32fe004e0", null ],
      [ "setGpuBufferAllocator", "class_ogre_1_1_terrain.html#afd269cb7c490b88d1aea4fccb4ac2451", null ],
      [ "getGpuBufferAllocator", "class_ogre_1_1_terrain.html#af1d8194d298ceec5609a7d1485bff7ca", null ],
      [ "_getNumIndexesForBatchSize", "class_ogre_1_1_terrain.html#a72c79185cbbc50e1ff016946ae14dca2", null ],
      [ "_populateIndexBuffer", "class_ogre_1_1_terrain.html#af01e8cc2a2055e30420f626269f3f38d", null ],
      [ "_calcSkirtVertexIndex", "class_ogre_1_1_terrain.html#a2ba2f7a6eb2c9356d6bddaf30fe72257", null ],
      [ "convertPosition", "class_ogre_1_1_terrain.html#a6ad6246dddf231e761c52af18397369f", null ],
      [ "convertPosition", "class_ogre_1_1_terrain.html#a09f6174d11a0339d9ff44775d48dee09", null ],
      [ "convertDirection", "class_ogre_1_1_terrain.html#a6a94314390459778b11cb4785dbd41ca", null ],
      [ "convertDirection", "class_ogre_1_1_terrain.html#a33bb06af72903323c8b8daa67c17abd7", null ],
      [ "setResourceGroup", "class_ogre_1_1_terrain.html#aacd2dcc94afbc3e8fbca6d6de1baedab", null ],
      [ "getResourceGroup", "class_ogre_1_1_terrain.html#afc98c5e76b60ff1b5bc1024a600e26cb", null ],
      [ "_getDerivedResourceGroup", "class_ogre_1_1_terrain.html#a55793a71b2ea6ed68fd04c45dfe63ed5", null ],
      [ "save", "class_ogre_1_1_terrain.html#accbc5c9286d1a898653c1b27e04f6099", null ],
      [ "save", "class_ogre_1_1_terrain.html#afce38d08848608e3bf4642678e289181", null ],
      [ "prepare", "class_ogre_1_1_terrain.html#aaf6c29ba4225758313190a53bb12e60c", null ],
      [ "prepare", "class_ogre_1_1_terrain.html#a2f08575d471649617945b200154478c5", null ],
      [ "prepare", "class_ogre_1_1_terrain.html#a20d7b036e25805405d3140b3751ec4b6", null ],
      [ "prepare", "class_ogre_1_1_terrain.html#a2b61cedddcd4ebe3b6c27068e2624d74", null ],
      [ "load", "class_ogre_1_1_terrain.html#ae7381fe2e7ea64304f59e7f10b6c90ec", null ],
      [ "load", "class_ogre_1_1_terrain.html#ae3fc60c0f8350b4872323ddf258d922d", null ],
      [ "load", "class_ogre_1_1_terrain.html#a78949cbc0a2a6d717b4606043b46d5c7", null ],
      [ "isLoaded", "class_ogre_1_1_terrain.html#af0c198af3449240a57dc63380e38a9fe", null ],
      [ "isModified", "class_ogre_1_1_terrain.html#ac09cc65643825f293320058bc6ed07ab", null ],
      [ "isHeightDataModified", "class_ogre_1_1_terrain.html#a0f29e0c116626bcb1bdb45835e0752cc", null ],
      [ "unload", "class_ogre_1_1_terrain.html#acee00b1d1d1d46633cd88b3b49f488cf", null ],
      [ "unprepare", "class_ogre_1_1_terrain.html#aa67c987848bb325bc3aef2b0ad7a9adf", null ],
      [ "getHeightData", "class_ogre_1_1_terrain.html#adc1a1c0afad76fb2de52058e23ffebc2", null ],
      [ "getHeightData", "class_ogre_1_1_terrain.html#a0457855b262d6491693709aecc661c07", null ],
      [ "getHeightAtPoint", "class_ogre_1_1_terrain.html#ac329134ec2c2ff88fa05dcb9ff1a2821", null ],
      [ "setHeightAtPoint", "class_ogre_1_1_terrain.html#a51979e546b48f5f6cc1676bc45e62007", null ],
      [ "getHeightAtTerrainPosition", "class_ogre_1_1_terrain.html#ae50846c3688082ececfe0d56ed78c792", null ],
      [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain.html#a7719018dcfb417865f00ddeef7b0951b", null ],
      [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain.html#ad365d761359884e56a7c0164086a57d9", null ],
      [ "getDeltaData", "class_ogre_1_1_terrain.html#a957880834cd9bd2b4ecb0aec124d838a", null ],
      [ "getDeltaData", "class_ogre_1_1_terrain.html#acf60757185ccbb975ae6fcec74143015", null ],
      [ "getPoint", "class_ogre_1_1_terrain.html#a6999afcf4ddfa84fbd291d0d1e3bc7f7", null ],
      [ "getPointFromSelfOrNeighbour", "class_ogre_1_1_terrain.html#ad0faeda25da323eaf9d8a2a8cab3cdf1", null ],
      [ "getPoint", "class_ogre_1_1_terrain.html#ace4a475574f656cc941df6af61968c83", null ],
      [ "getPointTransform", "class_ogre_1_1_terrain.html#a909f82eee09876149fdd36a49fb5858a", null ],
      [ "getTerrainVector", "class_ogre_1_1_terrain.html#a61849058085ae7cb6c0e16bb5c21cb03", null ],
      [ "getTerrainVector", "class_ogre_1_1_terrain.html#abb4ffa0b942aca1273cc6af52c2f2b81", null ],
      [ "getTerrainVectorAlign", "class_ogre_1_1_terrain.html#aad404a040c30d1138b406cff801e1b56", null ],
      [ "getTerrainVectorAlign", "class_ogre_1_1_terrain.html#af37504438f3cca3341419bbf43b28331", null ],
      [ "getVector", "class_ogre_1_1_terrain.html#a9831992c806d7b12114acdf35fc40aff", null ],
      [ "getVector", "class_ogre_1_1_terrain.html#af8cafe25232ec796bdb2ae229de6d590", null ],
      [ "getVectorAlign", "class_ogre_1_1_terrain.html#a00dd54e0cf38fac3e729bf481761a672", null ],
      [ "getVectorAlign", "class_ogre_1_1_terrain.html#a539d01d15e180e7c67727884badd5b7d", null ],
      [ "getPosition", "class_ogre_1_1_terrain.html#a19d92cbdb6f2dc3ff5bc8e57ee3df8dc", null ],
      [ "getPosition", "class_ogre_1_1_terrain.html#a4f12c4926b592f118508ee06b84eb220", null ],
      [ "getTerrainPosition", "class_ogre_1_1_terrain.html#aac94de7f1d8908a2adc0432b05804a00", null ],
      [ "getTerrainPosition", "class_ogre_1_1_terrain.html#a7db38251c418f66b2615037babfe781d", null ],
      [ "getPositionAlign", "class_ogre_1_1_terrain.html#af6b0f1642a0f159d6000594ccf006736", null ],
      [ "getPositionAlign", "class_ogre_1_1_terrain.html#a6f04aa8304bb033f4d33b64e08f05410", null ],
      [ "getTerrainPositionAlign", "class_ogre_1_1_terrain.html#a3fb22ca5067bb7f2b5b6d29f6e64a2b0", null ],
      [ "getTerrainPositionAlign", "class_ogre_1_1_terrain.html#a1b38900f2914d915b54dc3ce1d37eb40", null ],
      [ "getAlignment", "class_ogre_1_1_terrain.html#a7b0821197e537ceeff981835c0c127e2", null ],
      [ "getSize", "class_ogre_1_1_terrain.html#aa23d586fa8023d7992107388bec2d0bd", null ],
      [ "setSize", "class_ogre_1_1_terrain.html#a94a15b828bc003a3bc6a019c9fbbd2ff", null ],
      [ "getMaxBatchSize", "class_ogre_1_1_terrain.html#a33059cbc4162471869976806c34038e6", null ],
      [ "getMinBatchSize", "class_ogre_1_1_terrain.html#afdd76575197788ad0da8d138ab289254", null ],
      [ "getWorldSize", "class_ogre_1_1_terrain.html#abf52cde19183386c011d27a3e190cd7a", null ],
      [ "setWorldSize", "class_ogre_1_1_terrain.html#ad807304e85ba44ddb02aa7cbd639ef4b", null ],
      [ "getLayerCount", "class_ogre_1_1_terrain.html#a1b6d6be6683260c79d51cb5d9a8ca6be", null ],
      [ "getLayerDeclaration", "class_ogre_1_1_terrain.html#aaef840fb3b03d299b83077239122b695", null ],
      [ "addLayer", "class_ogre_1_1_terrain.html#a70a42e6eb37cb024b4573fc912e219b4", null ],
      [ "addLayer", "class_ogre_1_1_terrain.html#a1b09422cf8baa9b8dddd45290de9a666", null ],
      [ "removeLayer", "class_ogre_1_1_terrain.html#ae0b3ec5f09b44fdc3b83f0535c2d1a27", null ],
      [ "replaceLayer", "class_ogre_1_1_terrain.html#ae052005afc7eb71b24aef24fc22dd7e0", null ],
      [ "getMaxLayers", "class_ogre_1_1_terrain.html#a891a8c6a16efd6ecf16508e21cade01e", null ],
      [ "getLayerWorldSize", "class_ogre_1_1_terrain.html#a30d2fed380ea0b55b182cccf77670108", null ],
      [ "setLayerWorldSize", "class_ogre_1_1_terrain.html#a4447c7ef2269781192e5b637035b08fc", null ],
      [ "getLayerUVMultiplier", "class_ogre_1_1_terrain.html#ac38fc212b7a4d6a21843518c237cc44d", null ],
      [ "getLayerTextureName", "class_ogre_1_1_terrain.html#acfbf3bcc122a028d53ea35cad9e1eaaa", null ],
      [ "setLayerTextureName", "class_ogre_1_1_terrain.html#af1dc74d66c4f3867a484d09cf2063fbc", null ],
      [ "getLayerBlendMapSize", "class_ogre_1_1_terrain.html#a148549dc9a5d14725b5c44256638e8ad", null ],
      [ "getLightmapSize", "class_ogre_1_1_terrain.html#ae0168de61d9cc2f640d081538ad4ded9", null ],
      [ "getLightmap", "class_ogre_1_1_terrain.html#a6eea690ea25ed524f7c5fdb840b050a9", null ],
      [ "getCompositeMapSize", "class_ogre_1_1_terrain.html#a3740cb23e839b4a98e60c18b559d1309", null ],
      [ "getCompositeMap", "class_ogre_1_1_terrain.html#a21d313fdb0d84c403075a8c05a16940e", null ],
      [ "getPosition", "class_ogre_1_1_terrain.html#aa2ab5629b96f5fd91fec05edca29812a", null ],
      [ "setPosition", "class_ogre_1_1_terrain.html#aa87ddbb08f493d0901594fe6e3f4cafe", null ],
      [ "_getRootSceneNode", "class_ogre_1_1_terrain.html#a199fe8f1cab6aef966eea1b66c9f4b39", null ],
      [ "dirty", "class_ogre_1_1_terrain.html#aab69f3dead87b53b84784c7d7d325f68", null ],
      [ "dirtyRect", "class_ogre_1_1_terrain.html#a0a9de436fad8d6f3a95b1b78314fb736", null ],
      [ "_dirtyCompositeMapRect", "class_ogre_1_1_terrain.html#aa40d40d6f3de43fa0651079673145b95", null ],
      [ "dirtyLightmapRect", "class_ogre_1_1_terrain.html#a0852e0efabe0cbaf49277dbb261a5490", null ],
      [ "dirtyLightmap", "class_ogre_1_1_terrain.html#a9e432dfa8261600759fb020c09c169a1", null ],
      [ "update", "class_ogre_1_1_terrain.html#ae1ebf4ca9e17f173a0d516d92aed411e", null ],
      [ "updateGeometry", "class_ogre_1_1_terrain.html#a8e7fc528309dff0459e1558971a31d00", null ],
      [ "updateGeometryWithoutNotifyNeighbours", "class_ogre_1_1_terrain.html#a6c319d29b618e68b9a8d6dd3b0652dcb", null ],
      [ "updateDerivedData", "class_ogre_1_1_terrain.html#aa11183930beb39da27e84ca66673ef00", null ],
      [ "updateCompositeMap", "class_ogre_1_1_terrain.html#a84b12bda4d87a9145c5b131166275fd3", null ],
      [ "updateCompositeMapWithDelay", "class_ogre_1_1_terrain.html#a5d4659018c697f0a2fae1192f81ede4a", null ],
      [ "getSkirtSize", "class_ogre_1_1_terrain.html#a607e4aebdee75f7d26c279607d819976", null ],
      [ "getNumLodLevels", "class_ogre_1_1_terrain.html#a2edb50f75fb20e41b169c86cbffceadc", null ],
      [ "getNumLodLevelsPerLeaf", "class_ogre_1_1_terrain.html#aeb53dbed1ad2cb6cb22cefefa8039c68", null ],
      [ "calculateHeightDeltas", "class_ogre_1_1_terrain.html#a57b254a77b1c0fe87a34366ab08db4f3", null ],
      [ "finaliseHeightDeltas", "class_ogre_1_1_terrain.html#a1da607007f9aa988b80df8d3036e187e", null ],
      [ "calculateNormals", "class_ogre_1_1_terrain.html#a90f92130d910fa3d1f2acb6870acdec4", null ],
      [ "finaliseNormals", "class_ogre_1_1_terrain.html#a19862c05e3b50f4464a41e48c12c5245", null ],
      [ "calculateLightmap", "class_ogre_1_1_terrain.html#a1d26ac546212deb98d330775aa4c9e01", null ],
      [ "finaliseLightmap", "class_ogre_1_1_terrain.html#a36a0e738c270ab2d804446f3e93ae651", null ],
      [ "getResolutionAtLod", "class_ogre_1_1_terrain.html#afe71e5b01aa9db756587fadb27eb2a83", null ],
      [ "rayIntersects", "class_ogre_1_1_terrain.html#a66f5889d081e8e45d803e3c0abf0a35a", null ],
      [ "getAABB", "class_ogre_1_1_terrain.html#a64429e495a609ecb6f22a23aa3ed4037", null ],
      [ "getWorldAABB", "class_ogre_1_1_terrain.html#ad0f38e00e35fe85b04ed010a27433341", null ],
      [ "getMinHeight", "class_ogre_1_1_terrain.html#a2511163a9389cff84b1dfecdd863b381", null ],
      [ "getMaxHeight", "class_ogre_1_1_terrain.html#a8dc48d60a3f7e6a152b6757baf32c513", null ],
      [ "getBoundingRadius", "class_ogre_1_1_terrain.html#aa250d15148f1cbf87777ff36a628da9e", null ],
      [ "getMaterial", "class_ogre_1_1_terrain.html#aba442116bbed4a35f60b8565ff1c7318", null ],
      [ "_getMaterial", "class_ogre_1_1_terrain.html#ad7dddc1d68a0936b4b07fa7054f042fc", null ],
      [ "getCompositeMapMaterial", "class_ogre_1_1_terrain.html#abde5a9931a278de23697fe6996a0e6d9", null ],
      [ "_getCompositeMapMaterial", "class_ogre_1_1_terrain.html#a53a08891b2dec0febd07bde5680598e7", null ],
      [ "getMaterialName", "class_ogre_1_1_terrain.html#adc32dec06092d0cdf5c89830aa217d41", null ],
      [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ac1f87183250b885c01270a68d80236e4", null ],
      [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a5f7edff06d941d5621aad56c7d19c939", null ],
      [ "getRenderQueueGroup", "class_ogre_1_1_terrain.html#a85c8ed1f55d5cf5300e2ccc2d02ab2f5", null ],
      [ "setRenderQueueGroup", "class_ogre_1_1_terrain.html#a9ff521bcc0fb0193d9105af627af5c0d", null ],
      [ "getVisibilityFlags", "class_ogre_1_1_terrain.html#a124354ea9deb52eced5e1d5a75a2b996", null ],
      [ "setVisibilityFlags", "class_ogre_1_1_terrain.html#a03a3ea2ce4dba4e2948a6b9d1fc02566", null ],
      [ "getQueryFlags", "class_ogre_1_1_terrain.html#abbfdc91237fe8c41297f4715e96b1a19", null ],
      [ "setQueryFlags", "class_ogre_1_1_terrain.html#a4b05d2eef470c736f23b6e3dbb5619d9", null ],
      [ "addQueryFlags", "class_ogre_1_1_terrain.html#ad7934e16e9ad7a0a272bb86d46c17b9e", null ],
      [ "removeQueryFlags", "class_ogre_1_1_terrain.html#aa0e26a4fd6e9897509bf7372388427ff", null ],
      [ "getLayerBlendMap", "class_ogre_1_1_terrain.html#a4c17d599a4b63584160403e162a30e39", null ],
      [ "getBlendTextureIndex", "class_ogre_1_1_terrain.html#abea533df30a7cec072f08f527978c095", null ],
      [ "getBlendTextureCount", "class_ogre_1_1_terrain.html#a9167eb4f73df66b86bc63a9aea34bb88", null ],
      [ "getBlendTextureCount", "class_ogre_1_1_terrain.html#afdd34b73ebfbf437789a8ef2a8cf1c54", null ],
      [ "getBlendTextures", "class_ogre_1_1_terrain.html#a1ee7590f6de4fa9a5d51c29e7fe610b3", null ],
      [ "getBlendTextureName", "class_ogre_1_1_terrain.html#ab6c399c76c55b4befe775f9ab2e0c6c7", null ],
      [ "setGlobalColourMapEnabled", "class_ogre_1_1_terrain.html#ac2b0283f89f542552c2e40e07899f95d", null ],
      [ "getGlobalColourMapEnabled", "class_ogre_1_1_terrain.html#aa55c99add54accbfe6542f53b1a34c12", null ],
      [ "getGlobalColourMapSize", "class_ogre_1_1_terrain.html#acd720425368a1c9e9152c01da3e3c3cd", null ],
      [ "getGlobalColourMap", "class_ogre_1_1_terrain.html#a7ec8a99d7ea299a4f13397aa3177cc68", null ],
      [ "widenRectByVector", "class_ogre_1_1_terrain.html#aff2c1091b6355257deabcae1755adec9", null ],
      [ "widenRectByVector", "class_ogre_1_1_terrain.html#a19739da0efce18871375737421846f1c", null ],
      [ "freeTemporaryResources", "class_ogre_1_1_terrain.html#a4ee732f95cf2b3c4aacb709db48fad1e", null ],
      [ "getLayerBlendTexture", "class_ogre_1_1_terrain.html#ae1afa9f6173f69047bdf0beb9906c483", null ],
      [ "getLayerBlendTextureIndex", "class_ogre_1_1_terrain.html#a74f835b3f72cc06589d38d0b6e012650", null ],
      [ "_setMorphRequired", "class_ogre_1_1_terrain.html#a2a65fb835fe22a425107ce43edf43219", null ],
      [ "_getMorphRequired", "class_ogre_1_1_terrain.html#a5c7d3147f12a6765dd39d7eb69587df7", null ],
      [ "_setNormalMapRequired", "class_ogre_1_1_terrain.html#a3dba1853267506fed228c02ea8ecfe16", null ],
      [ "_setLightMapRequired", "class_ogre_1_1_terrain.html#a915121f91285f370bd1a01842991ae03", null ],
      [ "_setCompositeMapRequired", "class_ogre_1_1_terrain.html#a10b9f303b81585c1b51d0c273f03a5dd", null ],
      [ "_getUseVertexCompression", "class_ogre_1_1_terrain.html#a3b379afd3348efd5c8e5a87f0b2d0729", null ],
      [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#aca2087cd57d5c80ccf2e983acddb1887", null ],
      [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#a2f98ad8c78b6046d4d4f4dcf9d367fae", null ],
      [ "getQuadTree", "class_ogre_1_1_terrain.html#a69e78ec7eab8aece2d20df966f0dce49", null ],
      [ "getTerrainNormalMap", "class_ogre_1_1_terrain.html#aadd272b751be4c855ef9233b7e4cd9ce", null ],
      [ "getNeighbour", "class_ogre_1_1_terrain.html#ae60272e5836071d30036915c13dcc5ec", null ],
      [ "setNeighbour", "class_ogre_1_1_terrain.html#aa0d9b7d033bd0b3c29c13e6151c93bd0", null ],
      [ "getOppositeNeighbour", "class_ogre_1_1_terrain.html#ad90008dc319c694b073fc1e6523e03c2", null ],
      [ "getNeighbourIndex", "class_ogre_1_1_terrain.html#a14e9fbfcb1edd236554880595b02899b", null ],
      [ "notifyNeighbours", "class_ogre_1_1_terrain.html#a9a1c32a11911a0ccea0eda01c86484a9", null ],
      [ "neighbourModified", "class_ogre_1_1_terrain.html#a5baccf626f31854f341910aa4c7c0500", null ],
      [ "raySelectNeighbour", "class_ogre_1_1_terrain.html#afd8906489c367ae1742b548f81b41da3", null ],
      [ "_dumpTextures", "class_ogre_1_1_terrain.html#a1ba82d7fe350ae72a2d748eb4e02b960", null ],
      [ "isDerivedDataUpdateInProgress", "class_ogre_1_1_terrain.html#a518a4dcf0c880eeadc3d0ae6ff4aa5b1", null ],
      [ "convertWorldToTerrainAxes", "class_ogre_1_1_terrain.html#a86553dfa0e4c39018d8ee23f96fe588d", null ],
      [ "convertTerrainToWorldAxes", "class_ogre_1_1_terrain.html#afb9983e073970fa2fa47ede55a7f16f6", null ],
      [ "writeLayerDeclaration", "class_ogre_1_1_terrain.html#a124c278790b4228e7dfe6a06575cf653", null ],
      [ "readLayerDeclaration", "class_ogre_1_1_terrain.html#ac78ab1806379267473d03a57dde9bbb8", null ],
      [ "writeLayerInstanceList", "class_ogre_1_1_terrain.html#a7b01d7b34a6cc4c890a393857276bf42", null ],
      [ "readLayerInstanceList", "class_ogre_1_1_terrain.html#a5ea9b366b0dead6adf4bb63382851a17", null ],
      [ "OGRE_RW_MUTEX", "class_ogre_1_1_terrain.html#a998e0575ce4f0385512363c1c8019047", null ],
      [ "waitForDerivedProcesses", "class_ogre_1_1_terrain.html#a8f8965d9490b13d8b156d57fc061558b", null ],
      [ "increaseLodLevel", "class_ogre_1_1_terrain.html#a6ca2d94a3062b2ae63620ff2b1121b25", null ],
      [ "decreaseLodLevel", "class_ogre_1_1_terrain.html#ac11979818981d2a7c09c1982479932b0", null ],
      [ "getHighestLodPrepared", "class_ogre_1_1_terrain.html#afcf5e4be38a9734b95e2a1578630b17d", null ],
      [ "getHighestLodLoaded", "class_ogre_1_1_terrain.html#a8c4feba3c0ec197a375173e90423e978", null ],
      [ "getTargetLodLevel", "class_ogre_1_1_terrain.html#a768bccd8d43b0b1f5ff5eaa513be60f3", null ],
      [ "TerrainLodManager", "class_ogre_1_1_terrain.html#a305c9e25905898002f056b3227b1ee65", null ],
      [ "TERRAIN_CHUNK_ID", "class_ogre_1_1_terrain.html#ad1b6d65618e1ebc55155214f3b10b337", null ],
      [ "TERRAIN_CHUNK_VERSION", "class_ogre_1_1_terrain.html#afd3641ddf000f3e2ca771408f558131b", null ],
      [ "TERRAIN_MAX_BATCH_SIZE", "class_ogre_1_1_terrain.html#a5c204799a40adae8b01411ec05dbc841", null ],
      [ "TERRAINLAYERDECLARATION_CHUNK_ID", "class_ogre_1_1_terrain.html#ac83d9fa6c4ba65db9c7ad66bbd01b0de", null ],
      [ "TERRAINLAYERDECLARATION_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a14ce718231ed706aec11489fc6843d76", null ],
      [ "TERRAINLAYERSAMPLER_CHUNK_ID", "class_ogre_1_1_terrain.html#a53d1561777a42b20c5aa5a42dd96bf9b", null ],
      [ "TERRAINLAYERSAMPLER_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a369a6d0c5e30874dd103c7089406be6c", null ],
      [ "TERRAINLAYERSAMPLERELEMENT_CHUNK_ID", "class_ogre_1_1_terrain.html#adf20ab502696a7e4acf28dec2ebdd0c7", null ],
      [ "TERRAINLAYERSAMPLERELEMENT_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a6b4dc148f017fbd6441bc81f79fe743d", null ],
      [ "TERRAINLAYERINSTANCE_CHUNK_ID", "class_ogre_1_1_terrain.html#acb18d059e425a9e6f7677d4dfb2d43ee", null ],
      [ "TERRAINLAYERINSTANCE_CHUNK_VERSION", "class_ogre_1_1_terrain.html#ac7837f27d59df9244743172d331e2fb3", null ],
      [ "TERRAINDERIVEDDATA_CHUNK_ID", "class_ogre_1_1_terrain.html#a50efd0b73343b76d8cfae1366cfd1cd0", null ],
      [ "TERRAINDERIVEDDATA_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a935d5fea06bddac979ae56c7fa13d9da", null ],
      [ "TERRAINGENERALINFO_CHUNK_ID", "class_ogre_1_1_terrain.html#a61228d1282e5e503848dab11a2c794fd", null ],
      [ "TERRAINGENERALINFO_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a3786f2f64dbc4a16984a607bfa53dd82", null ],
      [ "LOD_MORPH_CUSTOM_PARAM", "class_ogre_1_1_terrain.html#acc4dccaad096e6d2abb01dd4813b18d5", null ],
      [ "DERIVED_DATA_DELTAS", "class_ogre_1_1_terrain.html#adc4deb8ce09c46f3d6215ea1ff390959", null ],
      [ "DERIVED_DATA_NORMALS", "class_ogre_1_1_terrain.html#a633492f40707af756814bca31f0f35ba", null ],
      [ "DERIVED_DATA_LIGHTMAP", "class_ogre_1_1_terrain.html#a1ebde7f1f98abe26938397f7110c88f3", null ],
      [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ]
    ] ],
    [ "Ogre::TerrainAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod.html", [
      [ "~TerrainAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod.html#aceb9152f5d90b3477916a455cb9e453c", null ],
      [ "autoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod.html#a370a1a1fc2cd7ff9af7854fca1f1b11a", null ],
      [ "getStrategyId", "class_ogre_1_1_terrain_auto_update_lod.html#ac4f8917cf562b6ca232f5354fcfa13b3", null ]
    ] ],
    [ "Ogre::TerrainAutoUpdateLodByDistance", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html", [
      [ "autoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#aa3c5f7032acaa7eae8f7c7f558fe316b", null ],
      [ "getStrategyId", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#a92b1da2b733414d315deca08cf90ed87", null ]
    ] ],
    [ "Ogre::TerrainAutoUpdateLodFactory", "class_ogre_1_1_terrain_auto_update_lod_factory.html", [
      [ "getAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod_factory.html#a25bb17eed297bd5986ace6f2836e86df", null ]
    ] ],
    [ "Ogre::TerrainGlobalOptions", "class_ogre_1_1_terrain_global_options.html", [
      [ "TerrainGlobalOptions", "class_ogre_1_1_terrain_global_options.html#abdea5490ca3e3150e1cc90f08ad0c5e5", null ],
      [ "~TerrainGlobalOptions", "class_ogre_1_1_terrain_global_options.html#a2926f893a8ba2a09064aad63c3bf4472", null ],
      [ "getSkirtSize", "class_ogre_1_1_terrain_global_options.html#a49aa0d4d209532421cf6339d0b0a859a", null ],
      [ "setSkirtSize", "class_ogre_1_1_terrain_global_options.html#a1edb0e8e24ef3f8d7ef698b88eb97613", null ],
      [ "getLightMapDirection", "class_ogre_1_1_terrain_global_options.html#af0c8f5a722a5456dc78353cf1a7b4d54", null ],
      [ "setLightMapDirection", "class_ogre_1_1_terrain_global_options.html#a4f2c45cf37eb725be27e96b39383b622", null ],
      [ "getCompositeMapAmbient", "class_ogre_1_1_terrain_global_options.html#a2fd86ec6db3f3a4a8400dc82bcc45a5a", null ],
      [ "setCompositeMapAmbient", "class_ogre_1_1_terrain_global_options.html#a0db83e224e43b4b2139d98d7682fd537", null ],
      [ "getCompositeMapDiffuse", "class_ogre_1_1_terrain_global_options.html#a5ea57a564841347d75be91d192a83ae9", null ],
      [ "setCompositeMapDiffuse", "class_ogre_1_1_terrain_global_options.html#a39b7fdcd9e04c019bf99409ef55d855a", null ],
      [ "getCompositeMapDistance", "class_ogre_1_1_terrain_global_options.html#a631d34776b22f9491153cdc5bd22434b", null ],
      [ "setCompositeMapDistance", "class_ogre_1_1_terrain_global_options.html#aa80e448823ce5fff95245461f87d9927", null ],
      [ "getCastsDynamicShadows", "class_ogre_1_1_terrain_global_options.html#a7799e8003167a17a38fc04a67cf93a2e", null ],
      [ "setCastsDynamicShadows", "class_ogre_1_1_terrain_global_options.html#a9cdb0627494bf2d153ec2ffde2484bda", null ],
      [ "getMaxPixelError", "class_ogre_1_1_terrain_global_options.html#a15d4f736e32c8f1faa474ba60b9e2bde", null ],
      [ "setMaxPixelError", "class_ogre_1_1_terrain_global_options.html#a17a76921b32eaa417b109a811f2c4c81", null ],
      [ "getRenderQueueGroup", "class_ogre_1_1_terrain_global_options.html#a82c5cd78bcea99d94db8070e04a6e3ed", null ],
      [ "setRenderQueueGroup", "class_ogre_1_1_terrain_global_options.html#ae2c546b4465ef1e321f2cbc1895c4227", null ],
      [ "getVisibilityFlags", "class_ogre_1_1_terrain_global_options.html#a92f355a7fd402435d06b4176e26e0f2e", null ],
      [ "setVisibilityFlags", "class_ogre_1_1_terrain_global_options.html#a8b7b87457f57b14e1dce2d023a0229d8", null ],
      [ "setQueryFlags", "class_ogre_1_1_terrain_global_options.html#a7194f2b178f46f69211d630d081624a7", null ],
      [ "getQueryFlags", "class_ogre_1_1_terrain_global_options.html#a6fcce3f601e0e6b6a9c495f45fb36fc8", null ],
      [ "addQueryFlags", "class_ogre_1_1_terrain_global_options.html#aaccc644a84e01e88954086048502a7e1", null ],
      [ "removeQueryFlags", "class_ogre_1_1_terrain_global_options.html#ae7612bb654507fd6f0e148adca85aa41", null ],
      [ "getUseRayBoxDistanceCalculation", "class_ogre_1_1_terrain_global_options.html#a41a60bd9535039a3d29b07fdf4124b32", null ],
      [ "setUseRayBoxDistanceCalculation", "class_ogre_1_1_terrain_global_options.html#a405c05d36af7a415b4aadf05492976de", null ],
      [ "getDefaultMaterialGenerator", "class_ogre_1_1_terrain_global_options.html#a01856a71b813370bc57839da50eb76c8", null ],
      [ "setDefaultMaterialGenerator", "class_ogre_1_1_terrain_global_options.html#a6a95aff2e0ef49d043f4591833a7cb94", null ],
      [ "getLayerBlendMapSize", "class_ogre_1_1_terrain_global_options.html#abaaf803e7181e4151ae053f8f3b1ca54", null ],
      [ "setLayerBlendMapSize", "class_ogre_1_1_terrain_global_options.html#a629f5b31ac27bc8b19d0dcf9ddc9bc9f", null ],
      [ "getDefaultLayerTextureWorldSize", "class_ogre_1_1_terrain_global_options.html#a0da4e02bc802061f23c2756117e7f9a6", null ],
      [ "setDefaultLayerTextureWorldSize", "class_ogre_1_1_terrain_global_options.html#a6ee9f93b4bdb72f8de6562192db22dad", null ],
      [ "getDefaultGlobalColourMapSize", "class_ogre_1_1_terrain_global_options.html#a8ec03f22751bf4b7bf0baa24cf271799", null ],
      [ "setDefaultGlobalColourMapSize", "class_ogre_1_1_terrain_global_options.html#a67dd1f4bf48968238e845e2939d744a0", null ],
      [ "getLightMapSize", "class_ogre_1_1_terrain_global_options.html#a51e4e14773bb9a73d7cbfcc8c0f16bd5", null ],
      [ "setLightMapSize", "class_ogre_1_1_terrain_global_options.html#a62aaf2d6a7c072adadbacc3c517351f9", null ],
      [ "getCompositeMapSize", "class_ogre_1_1_terrain_global_options.html#a7a212edf66436826fbc090d69cb88766", null ],
      [ "setCompositeMapSize", "class_ogre_1_1_terrain_global_options.html#a0d449a2ed56acd7959eb5fc7d894025c", null ],
      [ "setDefaultResourceGroup", "class_ogre_1_1_terrain_global_options.html#a0aeba371e3e83537d3269e0da4a476b9", null ],
      [ "getDefaultResourceGroup", "class_ogre_1_1_terrain_global_options.html#acee57256d49d69fe526d15efb4b5aa3e", null ],
      [ "getUseVertexCompressionWhenAvailable", "class_ogre_1_1_terrain_global_options.html#a838b9b89f364717e59d89eeb59f789b2", null ],
      [ "setUseVertexCompressionWhenAvailable", "class_ogre_1_1_terrain_global_options.html#a099ad9ade850e0b6d3146989441c52bc", null ],
      [ "getSingleton", "class_ogre_1_1_terrain_global_options.html#afff21d5f6afe514f396517a2af9ab9ba", null ],
      [ "getSingletonPtr", "class_ogre_1_1_terrain_global_options.html#a1c6836150929e6b5e76c92f07dbd3cf2", null ]
    ] ],
    [ "Ogre::TerrainGroup", "class_ogre_1_1_terrain_group.html", [
      [ "RayResult", "struct_ogre_1_1_terrain_group_1_1_ray_result.html", [
        [ "RayResult", "struct_ogre_1_1_terrain_group_1_1_ray_result.html#a39e75d877662e2a244999fdd64e853a7", null ],
        [ "hit", "struct_ogre_1_1_terrain_group_1_1_ray_result.html#a951a4fd9e895ed4037426217e572f949", null ],
        [ "terrain", "struct_ogre_1_1_terrain_group_1_1_ray_result.html#ad195afe5791ad7c8779636bc392bd02f", null ],
        [ "position", "struct_ogre_1_1_terrain_group_1_1_ray_result.html#a298fe7a58f8ab623739287b108371519", null ]
      ] ],
      [ "TerrainSlot", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html", [
        [ "TerrainSlot", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#a0ad82e8d743bd33a60ace3a1539ea68c", null ],
        [ "~TerrainSlot", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#af4d92dabd602528794e810f838278dcb", null ],
        [ "freeInstance", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#a9a40615d7d5beb2c86b2a0dae6957ecd", null ],
        [ "x", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#a371c7d7ea4a4413f46dd5477c29b374c", null ],
        [ "y", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#adc3cf1b5a763e19fc639727169cf0f69", null ],
        [ "def", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#aa0cb112bc24303af1881f7849b7c0585", null ],
        [ "instance", "struct_ogre_1_1_terrain_group_1_1_terrain_slot.html#a6b03382c08998d29c07142f6dcc90709", null ]
      ] ],
      [ "TerrainSlotDefinition", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html", [
        [ "TerrainSlotDefinition", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a2e4c34e42faae3ec1d745e5cae8fb200", null ],
        [ "~TerrainSlotDefinition", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a3450d2187ead05af229621bfcc50b369", null ],
        [ "useImportData", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a360a024704762f345a7a91a04b955061", null ],
        [ "useFilename", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a53ec1a48d519900da5c77b8702b5067a", null ],
        [ "freeImportData", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a7ca4751611a934a1088bfecd55d94a33", null ],
        [ "filename", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a5b0c56d3b577d08fd3800f0399ac8bff", null ],
        [ "importData", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a13c37aea760bd2537db790c8cf6271ce", null ]
      ] ],
      [ "TerrainList", "class_ogre_1_1_terrain_group.html#abf87821742631bea71b9023c25086b1c", null ],
      [ "TerrainSlotMap", "class_ogre_1_1_terrain_group.html#ac57f832848da942340db29a5f7f02cde", null ],
      [ "TerrainIterator", "class_ogre_1_1_terrain_group.html#a15497d38a2ad5c76905ad7f22f665151", null ],
      [ "ConstTerrainIterator", "class_ogre_1_1_terrain_group.html#a28ce249f802a03bf7260885a156c9462", null ],
      [ "TerrainGroup", "class_ogre_1_1_terrain_group.html#a7be4b53fbb7f1edd7707c69b4ee883f4", null ],
      [ "TerrainGroup", "class_ogre_1_1_terrain_group.html#a1ceb1403ef71bd8c5badd1861f17a566", null ],
      [ "~TerrainGroup", "class_ogre_1_1_terrain_group.html#a8fa89b425d4ce101a4f3973096d204b2", null ],
      [ "getDefaultImportSettings", "class_ogre_1_1_terrain_group.html#a5892492da7c02967aff7e6eef177a131", null ],
      [ "setOrigin", "class_ogre_1_1_terrain_group.html#abdcbba7565eea5b03a5d508e2aba07b2", null ],
      [ "getOrigin", "class_ogre_1_1_terrain_group.html#ab8dcbc720107c95a95ef493fa9c86116", null ],
      [ "getAlignment", "class_ogre_1_1_terrain_group.html#ab18dbc2536fc791783e120191128ebab", null ],
      [ "getTerrainWorldSize", "class_ogre_1_1_terrain_group.html#a1de8ba19022006b0c276fc5cd6d0aa34", null ],
      [ "setTerrainWorldSize", "class_ogre_1_1_terrain_group.html#a49fc3c6d80e6a06527cd44773d67d0a8", null ],
      [ "getTerrainSize", "class_ogre_1_1_terrain_group.html#a7a03112ea42d5962e140fcd9a0c17365", null ],
      [ "setTerrainSize", "class_ogre_1_1_terrain_group.html#ae30c228ce95e1459276a461f0d11c511", null ],
      [ "getSceneManager", "class_ogre_1_1_terrain_group.html#a85c991de3f14150bbe7ef2854e8b98a2", null ],
      [ "setFilenameConvention", "class_ogre_1_1_terrain_group.html#ac8af5ccd3d5a76c48bdbca955146eb7b", null ],
      [ "setFilenamePrefix", "class_ogre_1_1_terrain_group.html#aa464da8d2945b6e8ff569c68cd75a6a1", null ],
      [ "setFilenameExtension", "class_ogre_1_1_terrain_group.html#a77f531317a2af432f2628fdbb0601cf9", null ],
      [ "getFilenamePrefix", "class_ogre_1_1_terrain_group.html#a9c9c3debf9cc13286bbec5bcf0985d5a", null ],
      [ "getFilenameExtension", "class_ogre_1_1_terrain_group.html#a752b530eb7a8bc9518ca181903c1a3c9", null ],
      [ "setResourceGroup", "class_ogre_1_1_terrain_group.html#ab6f752f831a9fdc36b64b1f0cc1d3da4", null ],
      [ "getResourceGroup", "class_ogre_1_1_terrain_group.html#acd22ce4fe7b6cf7b95dcf6f1c9465128", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a0dcd142d9931122fd8de4cd4ca9c4263", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a3339ab4895c8a8f5339dc789854abd65", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a5f80864c75d98bf4796a9f925b65eebb", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a1e6699ed42660600b9f4cef4ba9812f4", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a72463e9fad2427e3e0b9d55c9fe1c7f7", null ],
      [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a212c614fe05a4c09731b3c2d9227d1e2", null ],
      [ "loadAllTerrains", "class_ogre_1_1_terrain_group.html#ad1666853bba30ba6c5d98a5f2fc7d7ad", null ],
      [ "loadTerrain", "class_ogre_1_1_terrain_group.html#aa2b3aa6c682d8b60be016bc6e503bd3b", null ],
      [ "loadLegacyTerrain", "class_ogre_1_1_terrain_group.html#a5d53c0a3858a5bafe5b4b0109dfd585c", null ],
      [ "loadLegacyTerrain", "class_ogre_1_1_terrain_group.html#a1f745bc5408998dde991f619fde76611", null ],
      [ "unloadTerrain", "class_ogre_1_1_terrain_group.html#afce782965e3d453f9ceb97ae95780e6f", null ],
      [ "removeTerrain", "class_ogre_1_1_terrain_group.html#ac61b66e483e66bf0c860b6d9885aa5dd", null ],
      [ "removeAllTerrains", "class_ogre_1_1_terrain_group.html#afdf092661bbf77ba7e1d5080f2f3bbe2", null ],
      [ "saveAllTerrains", "class_ogre_1_1_terrain_group.html#a04ca28f8d5f4d47da77da4b71492ff4c", null ],
      [ "getTerrainDefinition", "class_ogre_1_1_terrain_group.html#adce0ecf963861375cbd8233d49fd16aa", null ],
      [ "getTerrain", "class_ogre_1_1_terrain_group.html#a135d96938c39c1a734b31844f5d08d1c", null ],
      [ "freeTemporaryResources", "class_ogre_1_1_terrain_group.html#a6f1921036f2e2a12087c5ee792a03492", null ],
      [ "update", "class_ogre_1_1_terrain_group.html#abde345652ad41719d6f87232096c281e", null ],
      [ "updateGeometry", "class_ogre_1_1_terrain_group.html#a0b073d61ff3bd590a3a1a928a896da9a", null ],
      [ "updateDerivedData", "class_ogre_1_1_terrain_group.html#af9191a938f220f960128fdf7d30acc88", null ],
      [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain_group.html#a0ef435c6c37de37ae09c8874c8fe58dc", null ],
      [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain_group.html#a404abe9c1da4ae4f794384ef2ddff94d", null ],
      [ "rayIntersects", "class_ogre_1_1_terrain_group.html#ad3f690494e45dbe2ee5673e97afbc42d", null ],
      [ "boxIntersects", "class_ogre_1_1_terrain_group.html#a1f7a354c649351e5796ca71b764b03b6", null ],
      [ "sphereIntersects", "class_ogre_1_1_terrain_group.html#a11adbfd073f8384ba2a8713f15787380", null ],
      [ "convertWorldPositionToTerrainSlot", "class_ogre_1_1_terrain_group.html#a5719684dae085bfdbe81564151fdea1d", null ],
      [ "convertTerrainSlotToWorldPosition", "class_ogre_1_1_terrain_group.html#a09be3d6866674b23e390ea6d70db0ae5", null ],
      [ "isDerivedDataUpdateInProgress", "class_ogre_1_1_terrain_group.html#a9c8223383679e583761c8af009cd1cf8", null ],
      [ "getTerrainIterator", "class_ogre_1_1_terrain_group.html#ab3a50caf08ce5049ed0a15c0f610523d", null ],
      [ "getTerrainIterator", "class_ogre_1_1_terrain_group.html#a258a6c8f9655fc48fd4afbfaf9f650dd", null ],
      [ "getTerrainSlots", "class_ogre_1_1_terrain_group.html#ac8bb7d5a26fdfeec8dc7110d46a41aec", null ],
      [ "packIndex", "class_ogre_1_1_terrain_group.html#ae56023a560b2b3e650d722e6e95e734c", null ],
      [ "unpackIndex", "class_ogre_1_1_terrain_group.html#a041018a20d3605dd54bdbdbca20df587", null ],
      [ "generateFilename", "class_ogre_1_1_terrain_group.html#a80e7857e742770fd6f6c97d3d68461c8", null ],
      [ "saveGroupDefinition", "class_ogre_1_1_terrain_group.html#a20a7cffbed2c46fef92c2b655781fa7a", null ],
      [ "saveGroupDefinition", "class_ogre_1_1_terrain_group.html#a653b5492ff3f70b0363c124bdc2824ad", null ],
      [ "loadGroupDefinition", "class_ogre_1_1_terrain_group.html#a24a0fc7a1be84cd44834842521481219", null ],
      [ "loadGroupDefinition", "class_ogre_1_1_terrain_group.html#ab2024c1b3890def8d88aa3a0436edf66", null ],
      [ "increaseLodLevel", "class_ogre_1_1_terrain_group.html#a29305c16f7e7ae31a69cdfcbde1f2905", null ],
      [ "decreaseLodLevel", "class_ogre_1_1_terrain_group.html#a31a307cb267f071a72defcfad0598745", null ],
      [ "setAutoUpdateLod", "class_ogre_1_1_terrain_group.html#ab9136e3fb9fd9b6e1421ad454fe7d53c", null ],
      [ "autoUpdateLod", "class_ogre_1_1_terrain_group.html#ac8d34ec8ee538ca6d917c7a6302310fd", null ],
      [ "autoUpdateLodAll", "class_ogre_1_1_terrain_group.html#a4c6fa825170af7191d061c273349cd88", null ],
      [ "getNumTerrainPrepareRequests", "class_ogre_1_1_terrain_group.html#aa6f3102a07e1768367b3c2e2c093c272", null ],
      [ "CHUNK_ID", "class_ogre_1_1_terrain_group.html#af5d1ab56ff789b227e25e2011877c224", null ],
      [ "CHUNK_VERSION", "class_ogre_1_1_terrain_group.html#a18b58f7ef72dae5943447a3167b61150", null ]
    ] ],
    [ "Ogre::TerrainLayerBlendMap", "class_ogre_1_1_terrain_layer_blend_map.html", [
      [ "TerrainLayerBlendMap", "class_ogre_1_1_terrain_layer_blend_map.html#a7ec621ee0931d9f630f800a8427c1f5d", null ],
      [ "~TerrainLayerBlendMap", "class_ogre_1_1_terrain_layer_blend_map.html#a374ef6e33f6dc7671fd6b6105dae759e", null ],
      [ "getParent", "class_ogre_1_1_terrain_layer_blend_map.html#a570224a2d45f7d65284a6ab79556b174", null ],
      [ "getLayerIndex", "class_ogre_1_1_terrain_layer_blend_map.html#a9e5059cad03d64d41f75538a44816b19", null ],
      [ "convertWorldToUVSpace", "class_ogre_1_1_terrain_layer_blend_map.html#ab12d294404bb840b5f6a76568e5fdfdc", null ],
      [ "convertUVToWorldSpace", "class_ogre_1_1_terrain_layer_blend_map.html#a44ac5a3109a4234a298392e43df2edf0", null ],
      [ "convertUVToImageSpace", "class_ogre_1_1_terrain_layer_blend_map.html#a6d4912bb1b2e90443ca6ff3ecef9d57b", null ],
      [ "convertImageToUVSpace", "class_ogre_1_1_terrain_layer_blend_map.html#a8a50367f64f892ae402429f5f1926a60", null ],
      [ "convertImageToTerrainSpace", "class_ogre_1_1_terrain_layer_blend_map.html#abe74e7c92015442d95044887b492875d", null ],
      [ "convertTerrainToImageSpace", "class_ogre_1_1_terrain_layer_blend_map.html#ad7648915beabaa57229cfdfd4f9dd7dd", null ],
      [ "getBlendValue", "class_ogre_1_1_terrain_layer_blend_map.html#a5ad44e9cf42c7e21a873650b3daadcfc", null ],
      [ "setBlendValue", "class_ogre_1_1_terrain_layer_blend_map.html#a811f39e7d94c32273bf67c240762c0ac", null ],
      [ "getBlendPointer", "class_ogre_1_1_terrain_layer_blend_map.html#ab11bb7c151cc902561f4f2511b1171b2", null ],
      [ "dirty", "class_ogre_1_1_terrain_layer_blend_map.html#afc1e25e221980f7b3ce696dfc22223ca", null ],
      [ "dirtyRect", "class_ogre_1_1_terrain_layer_blend_map.html#aa1746e4fe6ba9de17b626c1d44f56879", null ],
      [ "blit", "class_ogre_1_1_terrain_layer_blend_map.html#a59d79d1b5da14f42d93cdea553d50b5b", null ],
      [ "blit", "class_ogre_1_1_terrain_layer_blend_map.html#a4e753bc130ea3731f71f90ab9c8f53c5", null ],
      [ "loadImage", "class_ogre_1_1_terrain_layer_blend_map.html#a69fc5e9bc78cbd909bdcc5b535c9c60a", null ],
      [ "loadImage", "class_ogre_1_1_terrain_layer_blend_map.html#a41e4f2242cc050b1f965bfa16740758b", null ],
      [ "loadImage", "class_ogre_1_1_terrain_layer_blend_map.html#ae9713419de094e337f0dcef41dd9302d", null ],
      [ "update", "class_ogre_1_1_terrain_layer_blend_map.html#a7b84ae6db639c23977a433047ec955bb", null ]
    ] ],
    [ "Ogre::TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html", [
      [ "TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html#a8cf27ef7b384897c434ea13670fb3231", null ],
      [ "TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html#a99aefff53a235d471bb54d65c8ec0483", null ],
      [ "alias", "struct_ogre_1_1_terrain_layer_sampler.html#ade7747cc8625094da5ed01bc5ab3e19c", null ],
      [ "format", "struct_ogre_1_1_terrain_layer_sampler.html#acbf57cf471d575ffc862c50d15bad9b0", null ]
    ] ],
    [ "Ogre::TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html", [
      [ "LoadLodRequest", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html", [
        [ "LoadLodRequest", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#a3c4ff828ba353197bb73965263f71b02", null ],
        [ "requestee", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#afa635e167e34d5bc7a75602205410928", null ],
        [ "currentPreparedLod", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#a60d97f1a3b8de4e85d4e76ae3f223530", null ],
        [ "currentLoadedLod", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#ae024346224789e5c73fa9b02096277e3", null ],
        [ "requestedLod", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#aef02279bce06791298afaf3defc002b6", null ]
      ] ],
      [ "LodInfo", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html", [
        [ "treeStart", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a0f891ce26a83a44aa6a3478ffe58e335", null ],
        [ "treeEnd", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a2018decb1162dedf8e1904d9df092d53", null ],
        [ "isLast", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a3d3eaf36cee2c6b6cb64bad691cd98f6", null ],
        [ "resolution", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a872db0ab4ff69396406a84eedf7f194a", null ],
        [ "size", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#ae043b0b854b4dedb4f658b4f37e12727", null ]
      ] ],
      [ "LodData", "class_ogre_1_1_terrain_lod_manager.html#af4f58f0e55b2be3751224540ca56afae", null ],
      [ "LodsData", "class_ogre_1_1_terrain_lod_manager.html#aae4e8b93b5c0d7a49eaa9f5acc0c939d", null ],
      [ "TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#ab5f4ef928bce023bc3ac359191e8c379", null ],
      [ "TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#a9a14a5692b839d0c0a68c0111fb9192a", null ],
      [ "~TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#adb27b3785755085b8aadf0c46a35bc27", null ],
      [ "open", "class_ogre_1_1_terrain_lod_manager.html#a72dc6e789390e1a53e36fafff3dd0a83", null ],
      [ "close", "class_ogre_1_1_terrain_lod_manager.html#a465ed43292cb995eaf83e17754d12841", null ],
      [ "isOpen", "class_ogre_1_1_terrain_lod_manager.html#a94980c3f507f89eb98a92bb551b91a60", null ],
      [ "updateToLodLevel", "class_ogre_1_1_terrain_lod_manager.html#a8c073c4b9f1f84603e008f0fd04d5384", null ],
      [ "saveLodData", "class_ogre_1_1_terrain_lod_manager.html#a30145b19986f072ec285f6e5bce8f448", null ],
      [ "fillBufferAtLod", "class_ogre_1_1_terrain_lod_manager.html#a116f798c0ba155a908fcbc662f762ee6", null ],
      [ "readLodData", "class_ogre_1_1_terrain_lod_manager.html#ae6f0f99c71b2dddeb2e7e4d99a9ca351", null ],
      [ "waitForDerivedProcesses", "class_ogre_1_1_terrain_lod_manager.html#aec80ac85598d91c1605525ef54c23e48", null ],
      [ "getHighestLodPrepared", "class_ogre_1_1_terrain_lod_manager.html#ab210c1e9044d216a961868bfee080510", null ],
      [ "getHighestLodLoaded", "class_ogre_1_1_terrain_lod_manager.html#af541299c989d42d4067da3d8a3665e3f", null ],
      [ "getTargetLodLevel", "class_ogre_1_1_terrain_lod_manager.html#aa7efa60b04102e08f549982ec8d82f4a", null ],
      [ "getLodInfo", "class_ogre_1_1_terrain_lod_manager.html#a05040b4f7d8503b9bc8777ac20c5f922", null ],
      [ "TERRAINLODDATA_CHUNK_ID", "class_ogre_1_1_terrain_lod_manager.html#a81d661a66427c9f136fa27e4b328b6db", null ],
      [ "TERRAINLODDATA_CHUNK_VERSION", "class_ogre_1_1_terrain_lod_manager.html#a70d6a9494e245040a45b5ee000334b1e", null ]
    ] ],
    [ "Ogre::TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html", [
      [ "Profile", "struct_ogre_1_1_terrain_material_generator_1_1_profile.html", [
        [ "~Profile", "struct_ogre_1_1_terrain_material_generator_1_1_profile.html#a0f8e8543ce925703ccc57298a9b59ffa", null ]
      ] ],
      [ "TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html#a533d059caa8ac039c9591fb47b1ea82e", null ],
      [ "~TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html#a1de7023a59600699ae10003ec5005fb4", null ],
      [ "getActiveProfile", "class_ogre_1_1_terrain_material_generator.html#ac4b5e697dd3c1b8955e764543a625429", null ],
      [ "_markChanged", "class_ogre_1_1_terrain_material_generator.html#ae6cdf5dafc5bbea8e8241b54689798de", null ],
      [ "getChangeCount", "class_ogre_1_1_terrain_material_generator.html#a7c66198986a8b44314be2aedcfbaf4fe", null ],
      [ "getLayerDeclaration", "class_ogre_1_1_terrain_material_generator.html#a865728fd9130cf62ac544f305fb5307f", null ],
      [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator.html#a73368819720d8898e87497463e27f21e", null ],
      [ "requestOptions", "class_ogre_1_1_terrain_material_generator.html#af56363e3dbbffde7872cf88b869565ac", null ],
      [ "generate", "class_ogre_1_1_terrain_material_generator.html#a0544cc90574d539f22ccf2018818b41b", null ],
      [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator.html#aecdc7427130af4e06ad56d7d4daefdc1", null ],
      [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator.html#a914f877ab8bb96f994160eb2b325a8cd", null ],
      [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator.html#a6402e1c3e9770043be75b845abbdc79a", null ],
      [ "updateCompositeMap", "class_ogre_1_1_terrain_material_generator.html#a4316a3691b3bf6d9f0164cc33758280e", null ],
      [ "updateParams", "class_ogre_1_1_terrain_material_generator.html#aed0ac64c47fa577fab20e844b02b0aa5", null ],
      [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator.html#a15db830ec2609de8e70e90861a30b8a7", null ],
      [ "setDebugLevel", "class_ogre_1_1_terrain_material_generator.html#aa53d7e61d51cc399bdce7afb807acff0", null ],
      [ "getDebugLevel", "class_ogre_1_1_terrain_material_generator.html#af9bef5cf6c1fe8d82675633066fc9e51", null ],
      [ "_renderCompositeMap", "class_ogre_1_1_terrain_material_generator.html#ad407c34ad20592d0924b88efa9b89434", null ],
      [ "_getCompositeMapRTT", "class_ogre_1_1_terrain_material_generator.html#a9a644d1701f65993222a4592ad917176", null ]
    ] ],
    [ "Ogre::TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html", [
      [ "SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html", [
        [ "SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa376d18067a63f6fb9b5d531c7ce7d4c", null ],
        [ "~SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#af77b3b4643c1250800d7427c09d030b7", null ],
        [ "generate", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aba3b26e555ef8fbaade9546e508c647e", null ],
        [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a3ce92aea13814d0bbb5d32654634e9a8", null ],
        [ "isLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ad1ad77bcb9bdd16acc999b17665620b6", null ],
        [ "setLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a53b717248396dc049de442f816b1e1fb", null ],
        [ "isLayerParallaxMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#adc3a8cfc9f04590aafbce270153b64be", null ],
        [ "setLayerParallaxMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a2f80249d865a97ceb69abff9d6333841", null ],
        [ "setLayerParallaxOcclusionMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a60d0dfbb80efbcb427cca6c4706967e9", null ],
        [ "isLayerOcclusionMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ae256c5404f7c67c0fdecc8d517287ded", null ],
        [ "isLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ae95cfc2e78b601cb172b53741182337f", null ],
        [ "setLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a2e61822498f7362d985a034f5226567a", null ],
        [ "setReceiveDynamicShadowsPSSM", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aedb34b1f7987eb59fcc39448bd9482a0", null ],
        [ "getReceiveDynamicShadowsPSSM", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ab9597d724542d8312dd95555076bfca1", null ],
        [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa507a0f10734cecdab43701169970016", null ],
        [ "setCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aaa64157d2401e518fcbc30b15911d9b8", null ],
        [ "setReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a37ba62bf3961095da08a3092bb3e3378", null ],
        [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac0d80ec80ca2029cdc7b53181998967e", null ]
      ] ],
      [ "TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html#ac41cdd05e80c7eed45f59a16e13ec740", null ],
      [ "~TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html#af5c5973e8e5c79a9134fad7b5a4f7212", null ],
      [ "getMainRenderState", "class_ogre_1_1_terrain_material_generator_a.html#a1a8e03b85c797366f2c6c9884562ab63", null ],
      [ "setLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a.html#aa4f97a55a7ec7305c27c60f921993513", null ],
      [ "setLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a0e433224bc7b1d34efd12615996806bc", null ],
      [ "getReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a.html#adc87e62203f4c7e6cccb77b9491a5114", null ],
      [ "setReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a199f18da0c87293bb5cb775a06471b28", null ],
      [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a.html#ab915f3711d239b3f7d06745a8fbe536b", null ],
      [ "getReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a.html#ae5c249f3f2f884728e74b5e1681cb6f7", null ],
      [ "isLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#ae541f5de2463055f1c9ac57c8a144b75", null ],
      [ "setCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a0fee94d1b14e1f02cb47f567dfa1a246", null ],
      [ "isCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a5242d90d28b34a6c0b661b5702d2fdc7", null ],
      [ "getActiveProfile", "class_ogre_1_1_terrain_material_generator_a.html#a3151937a7eebd65f64002666ccd38d54", null ],
      [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator_a.html#a53e943ef541981b795a3634ad32518ca", null ],
      [ "requestOptions", "class_ogre_1_1_terrain_material_generator_a.html#acddcb6b0c7158082b8e343693110e6cc", null ],
      [ "generate", "class_ogre_1_1_terrain_material_generator_a.html#a2d981ec289239a99c9c7b73775ee18fa", null ],
      [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator_a.html#a00024c995a93cb5f144c74c13c77f681", null ],
      [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a6c10400f3549cfa8727fd1cc88cc2d5b", null ],
      [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator_a.html#a80e17a839bcf6380b55f98b10a76699f", null ],
      [ "updateParams", "class_ogre_1_1_terrain_material_generator_a.html#a0767a5802f8f14ea6d0caba6ce45d414", null ],
      [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator_a.html#ad1f0ee06a094751cdf130503fda1ad17", null ]
    ] ],
    [ "Ogre::TerrainPagedWorldSection", "class_ogre_1_1_terrain_paged_world_section.html", [
      [ "TerrainDefiner", "class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html", [
        [ "~TerrainDefiner", "class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html#a943507b7a89e79094496a3b420931de2", null ],
        [ "define", "class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html#a5174c19ce0378ea535af62b64f103487", null ]
      ] ],
      [ "TerrainPagedWorldSection", "class_ogre_1_1_terrain_paged_world_section.html#ac4015e82e2e994378bfd26ce7303df7e", null ],
      [ "~TerrainPagedWorldSection", "class_ogre_1_1_terrain_paged_world_section.html#a7efd9deef0452bcbdca21d5ac1cf079c", null ],
      [ "init", "class_ogre_1_1_terrain_paged_world_section.html#a38c64c1c4595bd1d60d9a03a28c6530a", null ],
      [ "getTerrainGroup", "class_ogre_1_1_terrain_paged_world_section.html#a879013c429ee66c99c133d97b82baac6", null ],
      [ "setLoadRadius", "class_ogre_1_1_terrain_paged_world_section.html#a716af742bd2ca8df94604257bf9f8563", null ],
      [ "getLoadRadius", "class_ogre_1_1_terrain_paged_world_section.html#a7ac17a6a0f6bc7114784353e55f7f623", null ],
      [ "setHoldRadius", "class_ogre_1_1_terrain_paged_world_section.html#ab5d58805495931332246ec7d350db12d", null ],
      [ "getHoldRadius", "class_ogre_1_1_terrain_paged_world_section.html#a02f0eb8a31cc5523e3b4ad5c70899b13", null ],
      [ "setPageRange", "class_ogre_1_1_terrain_paged_world_section.html#a34d19a08bbfe7eb9def4c530fac62ffb", null ],
      [ "setPageRangeMinX", "class_ogre_1_1_terrain_paged_world_section.html#a51c280a9499de72bff05df90f422b776", null ],
      [ "setPageRangeMinY", "class_ogre_1_1_terrain_paged_world_section.html#a78c1590a87fbe2585844c7506ce2fbe0", null ],
      [ "setPageRangeMaxX", "class_ogre_1_1_terrain_paged_world_section.html#afef106bd3ba4aec795178319513c1229", null ],
      [ "setPageRangeMaxY", "class_ogre_1_1_terrain_paged_world_section.html#ad03153a817b969e8444bbd2ee0fce219", null ],
      [ "getPageRangeMinX", "class_ogre_1_1_terrain_paged_world_section.html#a52f13ecbd67ddb2812ee4bbda2af2d30", null ],
      [ "getPageRangeMinY", "class_ogre_1_1_terrain_paged_world_section.html#ad7ed51ef34902c0e264df859d11e48ec", null ],
      [ "getPageRangeMaxX", "class_ogre_1_1_terrain_paged_world_section.html#a87e0df4770a3be9ff30ae0cdd1fde041", null ],
      [ "getPageRangeMaxY", "class_ogre_1_1_terrain_paged_world_section.html#a93820dec8e88161aeaa4f65c5520dcca", null ],
      [ "getGridStrategy", "class_ogre_1_1_terrain_paged_world_section.html#a924ee057cdc64958a4fc9a56a5568a3a", null ],
      [ "getGridStrategyData", "class_ogre_1_1_terrain_paged_world_section.html#aff3ffe2df67866bfab9a5f054ab1609e", null ],
      [ "setLoadingIntervalMs", "class_ogre_1_1_terrain_paged_world_section.html#a9d208b0b43ad3838f95f9a3309c8ecba", null ],
      [ "getLoadingIntervalMs", "class_ogre_1_1_terrain_paged_world_section.html#a85a4fdb8bec2f5a7f2a13694e2400209", null ],
      [ "loadPage", "class_ogre_1_1_terrain_paged_world_section.html#a1a65128a0c2d3c56426c36a5e735428d", null ],
      [ "unloadPage", "class_ogre_1_1_terrain_paged_world_section.html#a0d84fb8359d1d53826db2c4eea8642ce", null ],
      [ "setDefiner", "class_ogre_1_1_terrain_paged_world_section.html#ad1ec44d3c798917114aa713a8281edf2", null ]
    ] ],
    [ "Ogre::TerrainPaging", "class_ogre_1_1_terrain_paging.html", [
      [ "TerrainPaging", "class_ogre_1_1_terrain_paging.html#a9626171913fa5a7a0750d1c7fde899be", null ],
      [ "~TerrainPaging", "class_ogre_1_1_terrain_paging.html#abd25fd10f56c13f1adc25946318338a8", null ],
      [ "createWorldSection", "class_ogre_1_1_terrain_paging.html#a4458c30d6e445823595616adcffadb92", null ]
    ] ],
    [ "Ogre::TerrainQuadTreeNode", "class_ogre_1_1_terrain_quad_tree_node.html", [
      [ "LodLevel", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html", [
        [ "LodLevel", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#aeddb9d375b1579a98ea3d22610908cc2", null ],
        [ "batchSize", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#a83acad7c18103f157856e75e8744ddb8", null ],
        [ "gpuIndexData", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#aacadac4ebd2adbe9d879b781faa90230", null ],
        [ "maxHeightDelta", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#a01670093b32d51d33f54146984fcd7ae", null ],
        [ "calcMaxHeightDelta", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#a97945e1567da64b6b5ef7022e4f63da8", null ],
        [ "lastTransitionDist", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#ac82a3ddf378272493d9d82100c17597a", null ],
        [ "lastCFactor", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#afd5d89ee1eaff154e44347c15af2fba3", null ]
      ] ],
      [ "LodLevelList", "class_ogre_1_1_terrain_quad_tree_node.html#ab2c83f326edecd38e6baa64a67521f9e", null ],
      [ "TerrainQuadTreeNode", "class_ogre_1_1_terrain_quad_tree_node.html#a6e8a302845886dc29bd29491f4e17111", null ],
      [ "~TerrainQuadTreeNode", "class_ogre_1_1_terrain_quad_tree_node.html#a525a7166daaa69292b2350de66784f58", null ],
      [ "getXOffset", "class_ogre_1_1_terrain_quad_tree_node.html#a21057fc9dca730125457d9fb0e7d4588", null ],
      [ "getYOffset", "class_ogre_1_1_terrain_quad_tree_node.html#ad0c51ed8fa618bd7dd8df1712141f742", null ],
      [ "isLeaf", "class_ogre_1_1_terrain_quad_tree_node.html#a93905e98254406040235005324cdb56e", null ],
      [ "getBaseLod", "class_ogre_1_1_terrain_quad_tree_node.html#abfeaf6e5696bb7a4b410216c9bbe0ca0", null ],
      [ "getLodCount", "class_ogre_1_1_terrain_quad_tree_node.html#a65a4d6c836307d05d01aaab86931094b", null ],
      [ "getChild", "class_ogre_1_1_terrain_quad_tree_node.html#adb1ddaace93774d95315915a954a0e2f", null ],
      [ "getParent", "class_ogre_1_1_terrain_quad_tree_node.html#a0eb56d7672b36b1403bc3eddc83bf786", null ],
      [ "getTerrain", "class_ogre_1_1_terrain_quad_tree_node.html#a83bc5b216d10d3168d68a5abf34131f1", null ],
      [ "prepare", "class_ogre_1_1_terrain_quad_tree_node.html#a440a2d098b05930f9c041bcce1fc3a90", null ],
      [ "prepare", "class_ogre_1_1_terrain_quad_tree_node.html#a6bac673d08ec9c0a2ede17eb16760aac", null ],
      [ "load", "class_ogre_1_1_terrain_quad_tree_node.html#a640fe3ce61b4c3d342ef6df439c27595", null ],
      [ "load", "class_ogre_1_1_terrain_quad_tree_node.html#a0116ccf6d9c0ded0c099210ca5024d0f", null ],
      [ "loadSelf", "class_ogre_1_1_terrain_quad_tree_node.html#a3a15c3342a52eccd843ef5710614bb73", null ],
      [ "unload", "class_ogre_1_1_terrain_quad_tree_node.html#a00fd0fa40466d2d443c7f65fb6c9c4fd", null ],
      [ "unload", "class_ogre_1_1_terrain_quad_tree_node.html#ae88989b432172c3b8321390abd245dcf", null ],
      [ "unprepare", "class_ogre_1_1_terrain_quad_tree_node.html#ad7ab8a8510a9a070486fcafd6d7acd02", null ],
      [ "save", "class_ogre_1_1_terrain_quad_tree_node.html#ac99dc8a7163f38da4944bffc25a76df7", null ],
      [ "getLodLevel", "class_ogre_1_1_terrain_quad_tree_node.html#ac437be8bb4f70332e67bab13c1ae9d3d", null ],
      [ "preDeltaCalculation", "class_ogre_1_1_terrain_quad_tree_node.html#a15a0aedbb91a7304d1802456f66ab6e5", null ],
      [ "notifyDelta", "class_ogre_1_1_terrain_quad_tree_node.html#ad3f99f3c71c1bff1d323007020f813d5", null ],
      [ "postDeltaCalculation", "class_ogre_1_1_terrain_quad_tree_node.html#a27b042a63b10b1eab460404b69054cf6", null ],
      [ "finaliseDeltaValues", "class_ogre_1_1_terrain_quad_tree_node.html#ac0400ce23ffa563bd4b310c946017b9a", null ],
      [ "assignVertexData", "class_ogre_1_1_terrain_quad_tree_node.html#ac03be7a6beb8e94439c51cdce1c2985e", null ],
      [ "useAncestorVertexData", "class_ogre_1_1_terrain_quad_tree_node.html#a20aec2a5359be7a4621188e98c6fdd4e", null ],
      [ "updateVertexData", "class_ogre_1_1_terrain_quad_tree_node.html#a7e0ca778e275f9fd825a97fcf223fe36", null ],
      [ "mergeIntoBounds", "class_ogre_1_1_terrain_quad_tree_node.html#a8700cbc04c5a88fc98fcb9801440ab01", null ],
      [ "resetBounds", "class_ogre_1_1_terrain_quad_tree_node.html#a9cce18f539fce6e45f71dfe533864eef", null ],
      [ "rectIntersectsNode", "class_ogre_1_1_terrain_quad_tree_node.html#af27dbb3371e5c51772e304eef37afb3f", null ],
      [ "rectContainsNode", "class_ogre_1_1_terrain_quad_tree_node.html#ab89d0817244bb68ab25500eec8c360c2", null ],
      [ "pointIntersectsNode", "class_ogre_1_1_terrain_quad_tree_node.html#a67493d0f5329e958ea9747e30b32fa55", null ],
      [ "getBoundingBox", "class_ogre_1_1_terrain_quad_tree_node.html#a390b02c9923941792b4f9870f61be02d", null ],
      [ "getBoundingRadius", "class_ogre_1_1_terrain_quad_tree_node.html#acd935c7ebebe4e9b2f5cf0b8695db60a", null ],
      [ "getLocalCentre", "class_ogre_1_1_terrain_quad_tree_node.html#a4b0024e42e7eff99a65abf0c81a9939c", null ],
      [ "getMinHeight", "class_ogre_1_1_terrain_quad_tree_node.html#a8c7eb959dae089d763e027ef3e459abd", null ],
      [ "getMaxHeight", "class_ogre_1_1_terrain_quad_tree_node.html#a1a2433c6e02f4434a43be08c6c1b9fc9", null ],
      [ "calculateCurrentLod", "class_ogre_1_1_terrain_quad_tree_node.html#a619cb859cf6a6501ab3c60bf2674cc1b", null ],
      [ "getCurrentLod", "class_ogre_1_1_terrain_quad_tree_node.html#a7302f88752914ed407eb1ce141b88a4f", null ],
      [ "isRenderedAtCurrentLod", "class_ogre_1_1_terrain_quad_tree_node.html#a38313e6b615d8df43e62ee721e576f22", null ],
      [ "isSelfOrChildRenderedAtCurrentLod", "class_ogre_1_1_terrain_quad_tree_node.html#a08466f3ed294f0ff9fc74feea3a9fff2", null ],
      [ "setCurrentLod", "class_ogre_1_1_terrain_quad_tree_node.html#a61cddd999eed248ede1e7015b17040e0", null ],
      [ "getLodTransition", "class_ogre_1_1_terrain_quad_tree_node.html#ae116a598286815a4702dc8159301d2e6", null ],
      [ "setLodTransition", "class_ogre_1_1_terrain_quad_tree_node.html#aef26e2fc5a8ce61b42111b85bd8bcbea", null ],
      [ "POSITION_BUFFER", "class_ogre_1_1_terrain_quad_tree_node.html#ad2d323266710dcd2847eeb20af7ed734", null ],
      [ "DELTA_BUFFER", "class_ogre_1_1_terrain_quad_tree_node.html#a570b17be150e8de773197f801a6a2a2e", null ]
    ] ],
    [ "Ogre::TerrainLayerBlendMapList", "group___terrain.html#ga13ef117fcdcdaf0c609c62f297d94c16", null ],
    [ "Ogre::TerrainLayerDeclaration", "group___terrain.html#ga97753876a164dbf20e586aa37750816c", null ],
    [ "Ogre::TerrainMaterialGeneratorPtr", "group___terrain.html#ga152d33cadca984511f2c0459562c7b0b", null ],
    [ "Ogre::TerrainAutoUpdateLodStrategy", "group___terrain.html#ga4e7b31c45dc1afba816f7d9bc71a301b", [
      [ "Ogre::NONE", "group___terrain.html#gga4e7b31c45dc1afba816f7d9bc71a301baf4ad13488a8b22a4309fdd0a7fb70db8", null ],
      [ "Ogre::BY_DISTANCE", "group___terrain.html#gga4e7b31c45dc1afba816f7d9bc71a301ba8b40189aba8887f4cdb96d967cd80460", null ]
    ] ]
];